netapp_ontap.models.igroup_target API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.igroup_target`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class IgroupTargetSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the IgroupTarget object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `firmware_revision: str GET`

    The firmware revision of the SCSI target specific to the OS type of the initiator group.

    Example: 9111

  `product_id: str GET`

    The product ID of the SCSI target.

    Example: LUN C-Mode

  `vendor_id: str GET`

    The vendor ID of the SCSI target.

    Example: NETAPP